@@ -99,11 +99,11 @@ function getYouPornUrl(index) {
                 request = new XMLHttpRequest();
                 request.onreadystatechange = function() {
                     if (request.readyState == XMLHttpRequest.HEADERS_RECEIVED) {
-                        var filePath = decodeURIComponent(request.getResponseHeader('location'));
+                        var videoUrl = decodeURIComponent(request.getResponseHeader('location'));
                         toggleBusy(false);
                         playVideo([{ "title": video.title,
                                    "thumbnail": video.thumbnail,
-                                   "filePath": filePath,
+                                   "url": videoUrl,
                                    "xtube": true
                     }]);
                     }
@@ -190,11 +190,11 @@ function getPornHubUrl(index) {
     request.onreadystatechange = function() {
         if (request.readyState == XMLHttpRequest.DONE) {
             var page = request.responseText;
-            var filePath = decodeURIComponent(page.split('"video_url","')[1].split('"')[0]);
+            var videoUrl = decodeURIComponent(page.split('"video_url","')[1].split('"')[0]);
             toggleBusy(false);
             playVideo([{ "title": video.title,
                        "thumbnail": video.thumbnail,
-                       "filePath": filePath,
+                       "url": videoUrl,
                        "xtube": true
         }]);
         }
@@ -242,11 +242,11 @@ function getTubeEightUrl(index) {
     request.onreadystatechange = function() {
         if (request.readyState == XMLHttpRequest.DONE) {
             var page = request.responseText;
-            var filePath = page.split('var videourl="')[1].split('"')[0];
+            var url = page.split('var videourl="')[1].split('"')[0];
             toggleBusy(false);
             playVideo([{ "title": video.title,
                        "thumbnail": video.thumbnail,
-                       "filePath": filePath,
+                       "url": videoUrl,
                        "xtube": true
         }]);
         }
